@@ -12,7 +12,7 @@ data structures. Whenever that happens, we define the new term here.
 import os
 from shlex import quote
 import sys
-from typing import Dict, List
+from typing import Dict, List, Union
 
 from things.database import Database
 
@@ -98,14 +98,18 @@ def tasks(uuid=None, include_items=False, **kwargs):  # noqa: C901
         - `deadline == True`, only include tasks _with_ a deadline.
         - `deadline == None` (default), then include all tasks.
 
+    trashed : bool or None, optional
+        - `trashed == True`, only include trashed tasks.
+        - `trashed == False`, (default), only include non-trashed tasks.
+        - `trashed == None`, include both kind of tasks.
+
     last : str, optional
-        Limit returned tasks to tasks created in the last X days or weeks.
+        Limit returned tasks to tasks created within the last X days,
+        weeks, or years. For example: '3d', '5w', or '1y'.
 
-        Takes as input an offset string of format 'X[d/w]' where X is a
-        non-negative  integer that is followed by 'd' or 'w' which stand
-        for 'days' and 'weeks', respectively.
-
-        For example: '3d' or '5w'.
+        Takes as input an offset string of the format 'X[d/w/y]' where X
+        is a non-negative  integer that is followed by 'd', 'w', or 'y'
+        which stand for 'days', 'weeks', and 'years', respectively.
 
     search_query : str, optional
         The string value is passed to the SQL LIKE operator. It can thus
@@ -121,6 +125,11 @@ def tasks(uuid=None, include_items=False, **kwargs):  # noqa: C901
     count_only : bool, default False
         Only output length of result. This is done by a SQL COUNT query.
 
+    print_sql : bool, default False
+        Print every SQL query performed. Some may contain '?' and ':'
+        characters, which correspond to SQLite parameter tokens.
+        See https://www.sqlite.org/lang_expr.html#varparam
+
     filepath : str, optional
         Any valid path of a SQLite database file generated by the Things app.
         If the environment variable `THINGSDB` is set, then use that path.
@@ -178,7 +187,7 @@ def tasks(uuid=None, include_items=False, **kwargs):  # noqa: C901
         # include items
         if task["type"] == "to-do":
             if task.get("checklist"):
-                task["checklist"] = database.get_checklist_items(task_uuid=task["uuid"])
+                task["checklist"] = database.get_checklist_items(task["uuid"])
         elif task["type"] == "project":
             project = task
             project["items"] = items = tasks(
@@ -340,6 +349,27 @@ def tags(title=None, include_items=False, **kwargs):
     return result
 
 
+def checklist_items(todo_uuid, **kwargs):
+    """
+    Read checklist items of to-dos into dicts.
+
+    Note: checklists are contained in the return value of
+    `things.todos(todo_uuid)` and `things.tasks(todo_uuid)`.
+
+    Parameters
+    ----------
+    todo_uuid : str, optional
+        A valid to-do uuid.
+
+    Returns
+    -------
+    list of dict
+        Checklist items.
+    """
+    database = pop_database(kwargs)
+    return database.get_checklist_items(todo_uuid=todo_uuid)
+
+
 # --------------------------------------------------
 # Utility API functions derived from above
 # --------------------------------------------------
@@ -419,26 +449,6 @@ def projects(uuid=None, **kwargs):
     return tasks(uuid=uuid, type="project", **kwargs)
 
 
-def checklist_items(uuid, **kwargs):
-    """
-    Read checklist items of a to-do into dicts.
-
-    Note: this checklist is also contained in the return value of
-    `things.todos(uuid)` and `things.tasks(uuid)`.
-
-    Parameters
-    ----------
-    uuid : str
-        A valid to-do uuid.
-
-    Returns
-    -------
-    list of dict
-        Checklist items of the to-do. If none, then return empty list.
-    """
-    return tasks(uuid=uuid, **kwargs).get("checklist", [])  # type: ignore
-
-
 # Filter by collections in the Things app sidebar.
 
 
@@ -463,7 +473,7 @@ def today(**kwargs):
     See `things.api.tasks` for details on the optional parameters.
     """
     database = pop_database(kwargs)
-    if not database.was_modified_today():
+    if not database.was_modified_today():  # pragma: no cover
         print(
             "[NOTE] The results reflect the state of the Things app "
             "when it was last run. If the results seem out of date, "
@@ -521,6 +531,15 @@ def logbook(**kwargs):
     return result
 
 
+def trash(**kwargs):
+    """
+    Read Trash tasks into dicts.
+
+    See `things.api.tasks` for details on the optional parameters.
+    """
+    return tasks(trashed=True, status=kwargs.pop("status", None), **kwargs)
+
+
 # Filter by various task properties
 
 
@@ -602,7 +621,7 @@ def last(offset, **kwargs):
 # Interact with Things app
 
 
-def token(**kwargs) -> str:
+def token(**kwargs) -> Union[str, None]:
     """
     Read the Things URL scheme authentication token.
 
@@ -636,8 +655,8 @@ def show(uuid):
     >>> tag = things.tags('Home')
     >>> things.show(tag['uuid'])
     """
-    uri = link(uuid)
-    os.system(f"open {quote(uri)}")
+    uri = link(uuid)  # pragma: no cover
+    os.system(f"open {quote(uri)}")  # pragma: no cover
 
 
 # Helper functions
@@ -645,7 +664,10 @@ def show(uuid):
 
 def pop_database(kwargs):
     """instantiate non-default database from `kwargs` if provided"""
-    filepath, database = kwargs.pop("filepath", None), kwargs.pop("database", None)
+    filepath = kwargs.pop("filepath", None)
+    database = kwargs.pop("database", None)
+    print_sql = kwargs.pop("print_sql", False)
+
     if not database:
-        database = Database(filepath=filepath)
+        database = Database(filepath=filepath, print_sql=print_sql)
     return database
